# -*- coding: utf-8 -*-
import json
import os
import sys


def analyze(name):
	directory = sys.argv[1]
	with open(os.path.join(directory, f'{name}_stats.csv'), 'r') as stats_fp:
		with open(os.path.join(directory, f'{name}.json'), 'r') as iperf_fp:
			iperf_data = json.load(iperf_fp)
			total_time = iperf_data['end']['sum_sent']['end']
			stats_fp.readline()
			stats_data = [tuple(float(value) for value in line.split(',')) for line in stats_fp.readlines()]
			last_signal_time = stats_data[-1][0]
			time_compensation = total_time - last_signal_time
			stats_data = [(line[0] + time_compensation,) + line[1:] for line in stats_data]
			with open(os.path.join(directory, f'{name}_analyze.csv'), 'w') as analyze_fp:
				analyze_fp.write('time,speed,line,level,temperature\n')
				for interval in iperf_data['intervals']:
					interval = interval['sum']
					interval_stats_data = [line for line in stats_data if line[0] >= interval['start'] and line[0] <= interval['end']]
					#if len(interval_stats_data) == 0:
					#	continue
					time = interval['start']
					speed = interval['bits_per_second'] / 1024**2
					line_quality = sum(line[1] for line in interval_stats_data) / len(interval_stats_data)
					link_level = sum(line[2] for line in interval_stats_data) / len(interval_stats_data)
					temperature = sum(line[3] for line in interval_stats_data) / len(interval_stats_data)
					analyze_fp.write(f'{time},{speed},{line_quality},{link_level},{temperature}\n')


def main():
	if len(sys.argv) != 2:
		sys.stderr.write(f'Usege {sys.argv[0]} directory\n')
		sys.exit(-1)
	analyze('download')
	analyze('upload')


if __name__ == "__main__":
	main()
